use anyhow::{Context, Result};
use clap::{Parser, Subcommand};
use std::fs;
use std::path::Path;

#[derive(Parser)]
#[command(author, version, about)]
struct Cli {
    #[command(subcommand)]
    command: Commands,
}

#[derive(Subcommand)]
enum Commands {
    /// 创建新的目录和文件
    New {
        /// 目录名称
        name: String,
        /// 要创建的文件名列表
        #[arg(short, long)]
        files: Vec<String>,
    },
    /// 在当前目录初始化文件
    Init {
        /// 要创建的文件名列表
        #[arg(short, long)]
        files: Vec<String>,
    },
}

fn main() -> Result<()> {
    let cli = Cli::parse();

    match cli.command {
        Commands::New { name, files } => create_directory_with_files(&name, &files),
        Commands::Init { files } => create_files(".", &files),
    }
}

fn create_directory_with_files(dir_name: &str, files: &[String]) -> Result<()> {
    // 创建目录
    fs::create_dir_all(dir_name)
        .with_context(|| format!("Failed to create directory '{}'", dir_name))?;

    // 创建文件
    create_files(dir_name, files)
}

fn create_files(dir: &str, files: &[String]) -> Result<()> {
    for file in files {
        let path = Path::new(dir).join(file);
        fs::File::create(&path)
            .with_context(|| format!("Failed to create file '{}'", path.display()))?;
    }
    Ok(())
}
